==> UltimatePOS-CodeBase-V6.8.zip: public/js/lang/nl.js <==
LANG = {
    'required': 'Vereist',
    'sure': 'Weet u het zeker?',
    'remove_product': 'Weet u zeker dat u het product wilt verwijderen?',
    'cancel_invoice': 'Weet u zeker dat u de factuur wilt annuleren?',
    'no_products': 'Geen producten toegevoegd',
    'paid_amount_is_less_than_payable': 'Betaald bedrag is minder dan het te betalen bedrag. Druk op OK om de verkoop in te dienen.',
    'paid_amount_is_more_than_payable': 'Betaald bedrag is meer dan het te betalen bedrag. \ nControleer.',
    'confirm_delete_role': 'Deze rol wordt verwijderd. \ N Weet u het zeker?',
    'sku_already_exists': 'SKU bestaat al.',
    'name_already_exists' : 'Product met deze naam bestaat al',
    'ref_no_already_exists': 'Referentienummer al gebruikt.',
    'out_of_stock': 'Artikel niet op voorraad',
    'delete_invoice_confirm': 'Deze instelling wordt verwijderd. \ n Weet u het zeker?',
    'add_name_as_new_customer': 'Toevoegen ":name" als nieuwe klant',
    "today": "Vandaag",
"yesterday": "Gisteren",
"last_7_days": "Laatste 7 dagen",
"last_30_days": "Laatste 30 dagen",
"this_month": "Deze maand",
"last_month": "Vorige maand",
"this_financial_year": "Huidig ​​boekjaar",
"clear": "Duidelijk",
"no_products_added": "Geen producten toegevoegd, eerst enkele producten toevoegen",
"some_error_in_input_field": "Ongeldige invoer, Controleer & probeer opnieuw !!",
"confirm_delete_expense_category": "Deze categorie wordt samen met alle uitgaven onder deze categorie verwijderd.",
"confirm_delete_expense": "Deze uitgave wordt verwijderd.",
"confirm_delete_payment": "Deze betaling wordt verwijderd.",
"confirm_delete_user": "Deze gebruiker wordt verwijderd",
"confirm_delete_contact": "Dit contact wordt verwijderd",
"confirm_delete_variation": "Deze variatie en alle bijbehorende waarden worden verwijderd.",
"confirm_tax_group": "Deze belastinggroep wordt verwijderd.",
"confirm_delete_category": "Deze categorie wordt samen met alle subcategorieën eronder verwijderd.",
"confirm_delete_unit": "Dit apparaat wordt verwijderd.",
"confirm_delete_tax_rate": "Dit belastingtarief wordt verwijderd.",
"confirm_delete_brand": "Dit merk zal worden verwijderd.",
"confirm_delete_barcode": "Deze barcode-instelling zal worden verwijderd.",
"add_name_as_new_product": "Toevoegen :term als nieuw product",
"no_products_found": "Geen overeenkomend product gevonden!",
"cancel": "Annuleer",
"ok": "OK",
"view_stock_details": "Voorraad bekijken voor elke variatie",
"tour_step1_title": "Application Tour",
"tour_step1_content": "Laten we de toepassing in zeven snelle stappen doorlopen ...",
"tour_step2_title": "Stap 1: winkeldetails",
"tour_step2_content": "Hier kunt u uw winkelgerelateerde informatie, basisinformatie, product-SKU, kortingen, belastingen en andere instellingen vinden.",
"tour_step3_title": "Stap 2: Resources toevoegen",
"tour_step4_title": "Stap 3: Leveranciers & Klanten",
"tour_step4_content": "Alle leveranciers en klanten voor uw winkel.",
"tour_step5_title": "Stap 4: Producten beheren",
"tour_step6_title": "Stap 5: Aankopen beheren",
"tour_step6_content": "Aankopen en betalingen beheren voor aankopen",
"tour_step7_title": "Step6: Verkoop beheren",
"tour_step7_content": "Verkoop -> POS, Gebruik dit scherm tijdens het verkopen van producten of het factureren van klant. Selecteer Locatie, Producten toevoegen en voltooien.",
"tour_step8_title": "Stap 7: Rapporten",
"tour_step8_content": "Bekijk analytische rapporten voor uw winkel. Deze rapporten helpen u algemene informatie te krijgen over de prestaties van uw bedrijf.",
"label_no_product_error": "Voeg ten minste één product toe.",
"confirm_delete_customer_group": "Deze klantengroep zal worden verwijderd.", 
"prev": "Vorige", 
"next": "Next", 
"end_tour": "Einde tour", 
"inc_tax": "Inclusief belasting", 
"exc_tax": "Exclusief belasting", 
"file_browse_label": "Browse ..", 
"remove": "Verwijderen", 
"apply": "Van toepassing zijn", 
"custom_range": "Aangepast bereik", 
"action": "Actie", 
"copy": "Kopiëren", 
"export_to_csv": "Exporteren naar CSV", 
"export_to_excel": "Exporteren naar Excel", 
"export_to_pdf": "Exporteren naar PDF", 
"print": "Afdrukken", 
"col_vis": "Kolomzichtbaarheid", 
"search": "Zoeken", 
"show": "Laten zien", 
"entries": "Entries", 
"table_emptyTable": "Geen data beschikbaar in de tabel", 
"table_info": "_START_ tot _END_ van _TOTAL_ vermeldingen", 
"table_infoEmpty": "0 tot 0 van 0 vermeldingen", 
"table_loadingRecords": "Bezig met laden...", 
"table_processing": "Verwerken...", 
"table_zeroRecords": "Geen overeenkomende records gevonden", 
"first": "Eerste", 
"last": "Laatste", 
"previous": "Vorige", 
"contact_id_already_exists": "Contact ID bestaat al", 
"register": "Registreren", 
"specify_business_name": "Geef uw bedrijfsnaam op", 
"password_min_length": "Wachtwoord moet minimaal 4 karakters zijn", 
"password_mismatch": "Wachtwoord komt niet overeen", 
"invalid_username": "Ongeldige gebruikersnaam of gebruikersnaam bestaat al",
'details': 'Details',
'select_location': 'U moet een locatie selecteren voordat u producten selecteert.',
'location_id_already_exists': 'Locatie-ID bestaat al',
'add_name_as_new_supplier': 'Voeg ":name" toe als nieuwe leverancier',
'all': 'Alle',
'filter_by_date': 'Filteren op datum',
'form_will_get_reset': 'Alle toegevoegde producten worden verwijderd.',
'tour_step3_content_modified': 'Voeg meerdere locaties, belastingtarieven, factuurinstellingen voor uw winkel toe.',
'tour_step5_content_modified': 'Producten toevoegen - eenvoudige of variabele producten <br> Creëer variaties voor variabele producten <br> Maak eenheden, merken en categorieën <br> Print labels',
"pos_max_qty_error": "Only :max_val :unit_name beschikbaar", 
"lot_max_qty_error": "Only :max_val :unit_name beschikbaar in de geselecteerde partij", 
"email_taken": "Dit e-mailadres is reeds in gebruik.", 
"loading": "Bezig met laden", 
"load_more": "Meer laden", 
"mobile": "Mobile", 
"something_went_wrong": "Er is iets fout gegaan", 
"max_rp_reached_error": "Maximum :max_points :rp_name beschikbaar", 
"min_order_total_error": "Minimale besteltotaal moet zijn :min_order om in te wisselen :rp_name", 
"this_year": "Dit jaar", 
"last_year": "Afgelopen jaar", 
"last_financial_year": "Laatste boekjaar", 
"this_month_last_year": "Deze maand vorig jaar", 
'enter_pin_here': 'Voer Pin Hier In',
'authentication_failed': 'Authenticatie mislukt!',
'authentication_successfull': 'Authenticatie succesvol',
'please_enter' : 'Voer alstublieft in',
'or_more_characters' : 'of meer karakters',
'name_already_exists' : 'Product met deze naam bestaat al',
// AI Assistance translations
'use_ai': 'AI gebruiken',
'image_added_successfully': 'Afbeelding succesvol toegevoegd',
'fill_required_fields': 'Vul verplichte velden in voordat u AI gebruikt',
'generating_description': 'Productbeschrijving genereren...',
'generating_image': 'Productafbeelding genereren...',
'processing': 'Verwerken...',
'use_description': 'Beschrijving gebruiken',
'use_image': 'Afbeelding gebruiken',
'submit': 'Verzenden',
'fill_name_brand_for_image': 'Vul productnaam en merk in voordat u de afbeelding genereert.',
'fill_name_brand_unit_for_ai': 'Vul productnaam, merk en eenheid in voordat u AI gebruikt.',
'something_went_wrong_try_again': 'Er is iets misgegaan, probeer het opnieuw',
 'invoice_number_already_exists': 'Factuurnummer bestaat al',
 'tax_number_already_exists' : 'Dit btw-nummer bestaat al',
 'missing_skus' : 'Ontbrekende SKU-codes',
};

==> UltimatePOS-CodeBase-V6.9.zip: public/js/lang/nl.js <==
LANG = {
    'required': 'Vereist',
    'sure': 'Weet u het zeker?',
    'remove_product': 'Weet u zeker dat u het product wilt verwijderen?',
    'cancel_invoice': 'Weet u zeker dat u de factuur wilt annuleren?',
    'no_products': 'Geen producten toegevoegd',
    'paid_amount_is_less_than_payable': 'Betaald bedrag is minder dan het te betalen bedrag. Druk op OK om de verkoop in te dienen.',
    'paid_amount_is_more_than_payable': 'Betaald bedrag is meer dan het te betalen bedrag. \ nControleer.',
    'confirm_delete_role': 'Deze rol wordt verwijderd. \ N Weet u het zeker?',
    'sku_already_exists': 'SKU bestaat al.',
    'name_already_exists' : 'Product met deze naam bestaat al',
    'ref_no_already_exists': 'Referentienummer al gebruikt.',
    'out_of_stock': 'Artikel niet op voorraad',
    'delete_invoice_confirm': 'Deze instelling wordt verwijderd. \ n Weet u het zeker?',
    'add_name_as_new_customer': 'Toevoegen ":name" als nieuwe klant',
    "today": "Vandaag",
"yesterday": "Gisteren",
"last_7_days": "Laatste 7 dagen",
"last_30_days": "Laatste 30 dagen",
"this_month": "Deze maand",
"last_month": "Vorige maand",
"this_financial_year": "Huidig ​​boekjaar",
"clear": "Duidelijk",
"no_products_added": "Geen producten toegevoegd, eerst enkele producten toevoegen",
"some_error_in_input_field": "Ongeldige invoer, Controleer & probeer opnieuw !!",
"confirm_delete_expense_category": "Deze categorie wordt samen met alle uitgaven onder deze categorie verwijderd.",
"confirm_delete_expense": "Deze uitgave wordt verwijderd.",
"confirm_delete_payment": "Deze betaling wordt verwijderd.",
"confirm_delete_user": "Deze gebruiker wordt verwijderd",
"confirm_delete_contact": "Dit contact wordt verwijderd",
"confirm_delete_variation": "Deze variatie en alle bijbehorende waarden worden verwijderd.",
"confirm_tax_group": "Deze belastinggroep wordt verwijderd.",
"confirm_delete_category": "Deze categorie wordt samen met alle subcategorieën eronder verwijderd.",
"confirm_delete_unit": "Dit apparaat wordt verwijderd.",
"confirm_delete_tax_rate": "Dit belastingtarief wordt verwijderd.",
"confirm_delete_brand": "Dit merk zal worden verwijderd.",
"confirm_delete_barcode": "Deze barcode-instelling zal worden verwijderd.",
"add_name_as_new_product": "Toevoegen :term als nieuw product",
"no_products_found": "Geen overeenkomend product gevonden!",
"cancel": "Annuleer",
"ok": "OK",
"view_stock_details": "Voorraad bekijken voor elke variatie",
"tour_step1_title": "Application Tour",
"tour_step1_content": "Laten we de toepassing in zeven snelle stappen doorlopen ...",
"tour_step2_title": "Stap 1: winkeldetails",
"tour_step2_content": "Hier kunt u uw winkelgerelateerde informatie, basisinformatie, product-SKU, kortingen, belastingen en andere instellingen vinden.",
"tour_step3_title": "Stap 2: Resources toevoegen",
"tour_step4_title": "Stap 3: Leveranciers & Klanten",
"tour_step4_content": "Alle leveranciers en klanten voor uw winkel.",
"tour_step5_title": "Stap 4: Producten beheren",
"tour_step6_title": "Stap 5: Aankopen beheren",
"tour_step6_content": "Aankopen en betalingen beheren voor aankopen",
"tour_step7_title": "Step6: Verkoop beheren",
"tour_step7_content": "Verkoop -> POS, Gebruik dit scherm tijdens het verkopen van producten of het factureren van klant. Selecteer Locatie, Producten toevoegen en voltooien.",
"tour_step8_title": "Stap 7: Rapporten",
"tour_step8_content": "Bekijk analytische rapporten voor uw winkel. Deze rapporten helpen u algemene informatie te krijgen over de prestaties van uw bedrijf.",
"label_no_product_error": "Voeg ten minste één product toe.",
"confirm_delete_customer_group": "Deze klantengroep zal worden verwijderd.", 
"prev": "Vorige", 
"next": "Next", 
"end_tour": "Einde tour", 
"inc_tax": "Inclusief belasting", 
"exc_tax": "Exclusief belasting", 
"file_browse_label": "Browse ..", 
"remove": "Verwijderen", 
"apply": "Van toepassing zijn", 
"custom_range": "Aangepast bereik", 
"action": "Actie", 
"copy": "Kopiëren", 
"export_to_csv": "Exporteren naar CSV", 
"export_to_excel": "Exporteren naar Excel", 
"export_to_pdf": "Exporteren naar PDF", 
"print": "Afdrukken", 
"col_vis": "Kolomzichtbaarheid", 
"search": "Zoeken", 
"show": "Laten zien", 
"entries": "Entries", 
"table_emptyTable": "Geen data beschikbaar in de tabel", 
"table_info": "_START_ tot _END_ van _TOTAL_ vermeldingen", 
"table_infoEmpty": "0 tot 0 van 0 vermeldingen", 
"table_loadingRecords": "Bezig met laden...", 
"table_processing": "Verwerken...", 
"table_zeroRecords": "Geen overeenkomende records gevonden", 
"first": "Eerste", 
"last": "Laatste", 
"previous": "Vorige", 
"contact_id_already_exists": "Contact ID bestaat al", 
"register": "Registreren", 
"specify_business_name": "Geef uw bedrijfsnaam op", 
"password_min_length": "Wachtwoord moet minimaal 4 karakters zijn", 
"password_mismatch": "Wachtwoord komt niet overeen", 
"invalid_username": "Ongeldige gebruikersnaam of gebruikersnaam bestaat al",
'details': 'Details',
'select_location': 'U moet een locatie selecteren voordat u producten selecteert.',
'location_id_already_exists': 'Locatie-ID bestaat al',
'add_name_as_new_supplier': 'Voeg ":name" toe als nieuwe leverancier',
'all': 'Alle',
'filter_by_date': 'Filteren op datum',
'form_will_get_reset': 'Alle toegevoegde producten worden verwijderd.',
'tour_step3_content_modified': 'Voeg meerdere locaties, belastingtarieven, factuurinstellingen voor uw winkel toe.',
'tour_step5_content_modified': 'Producten toevoegen - eenvoudige of variabele producten <br> Creëer variaties voor variabele producten <br> Maak eenheden, merken en categorieën <br> Print labels',
"pos_max_qty_error": "Only :max_val :unit_name beschikbaar", 
"lot_max_qty_error": "Only :max_val :unit_name beschikbaar in de geselecteerde partij", 
"email_taken": "Dit e-mailadres is reeds in gebruik.", 
"loading": "Bezig met laden", 
"load_more": "Meer laden", 
"mobile": "Mobile", 
"something_went_wrong": "Er is iets fout gegaan", 
"max_rp_reached_error": "Maximum :max_points :rp_name beschikbaar", 
"min_order_total_error": "Minimale besteltotaal moet zijn :min_order om in te wisselen :rp_name", 
"this_year": "Dit jaar", 
"last_year": "Afgelopen jaar", 
"last_financial_year": "Laatste boekjaar", 
"this_month_last_year": "Deze maand vorig jaar", 
'enter_pin_here': 'Voer Pin Hier In',
'authentication_failed': 'Authenticatie mislukt!',
'authentication_successfull': 'Authenticatie succesvol',
'please_enter' : 'Voer alstublieft in',
'or_more_characters' : 'of meer karakters',
'name_already_exists' : 'Product met deze naam bestaat al',
// AI Assistance translations
'use_ai': 'AI gebruiken',
'image_added_successfully': 'Afbeelding succesvol toegevoegd',
'fill_required_fields': 'Vul verplichte velden in voordat u AI gebruikt',
'generating_description': 'Productbeschrijving genereren...',
'generating_image': 'Productafbeelding genereren...',
'processing': 'Verwerken...',
'use_description': 'Beschrijving gebruiken',
'use_image': 'Afbeelding gebruiken',
'submit': 'Verzenden',
'fill_name_brand_for_image': 'Vul productnaam en merk in voordat u de afbeelding genereert.',
'fill_name_brand_unit_for_ai': 'Vul productnaam, merk en eenheid in voordat u AI gebruikt.',
'something_went_wrong_try_again': 'Er is iets misgegaan, probeer het opnieuw',
 'invoice_number_already_exists': 'Factuurnummer bestaat al',
 'tax_number_already_exists' : 'Dit btw-nummer bestaat al',
 'missing_skus' : 'Ontbrekende SKU-codes',
 'each': 'Elk',
 'total': 'Totaal',
        
    // Member profile related
    'diet_plan_applied_to_form_successfully': 'Dieetplan succesvol toegepast op formulier!',
    'workout_plan_saved_successfully': 'Trainingsplan succesvol opgeslagen!',
    'workout_plan_applied_to_form_successfully': 'Trainingsplan succesvol toegepast op formulier!',
};
